@@ -31,7 +31,7 @@
 queryRegulome <- function(query=NULL, 
                           format = "full",
                           url="http://www.regulomedb.org/results",
-                          timeout=10,
+                          timeout=100,
                           check_bad_snps=TRUE,
                           verbose=FALSE) {
   
@@ -89,14 +89,14 @@ queryRegulome <- function(query=NULL,
         print(e)
     })
     
-    for(i in 1:dim(res.table)[2]) {
-        res.table[,i] <- as.character(res.table[,i])
-        col.num.conv <- suppressWarnings(as.numeric(res.table[,i]))
-        na.rate <- length(which(is.na(col.num.conv)))/length(col.num.conv)
-        if(na.rate <= 0.5) {
-            res.table[,i] <- col.num.conv
-        }
-    }
+    #for(i in 1:dim(res.table)[2]) {
+    #    res.table[,i] <- as.character(res.table[,i])
+    #    col.num.conv <- suppressWarnings(as.numeric(res.table[,i]))
+    #    na.rate <- length(which(is.na(col.num.conv)))/length(col.num.conv)
+    #    if(na.rate <= 0.5) {
+    #        res.table[,i] <- col.num.conv
+    #    }
+    #}
     
     return(list(res.table=as_tibble(res.table), bad.snp.id=bad.snp.id))
 }
\ No newline at end of file
